==> musiccontrol-0.2.tar.gz: musiccontrol-0.2/src/dk/borderworlds/MusicVolume.java <==
// $Id: MusicVolume.java,v 1.6 2003/06/09 16:20:52 xi Exp $

/******************************************************************************
*    MusicControl - An advanced music player
*    Copyright (C) 2002,2003  Christian Laursen <xi@borderworlds.dk>
*
*    This program is free software; you can redistribute it and/or modify
*    it under the terms of the GNU General Public License as published by
*    the Free Software Foundation; either version 2 of the License, or
*    (at your option) any later version.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU General Public License for more details.
*
*    You should have received a copy of the GNU General Public License
*    along with this program; if not, write to the Free Software
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

package dk.borderworlds;

import java.util.Vector;
import java.io.File;

public class MusicVolume {
	private String directory;
	private int volumeId;

	public MusicVolume (String directory, int volumeId) {
		this.directory = directory;
		this.volumeId = volumeId;
	}

	public String getDirectory () {
		return directory;
	}

	public int getVolumeId () {
		return volumeId;
	}

	public void rescan (Vector songs) {
		int i;
		Song song;

		for (i = 0; i < songs.size(); ++i) {
			song = (Song)songs.get(i);
			if (song.fromVolume(volumeId)) {
				songs.removeElementAt(i--);
			}
		}

		File dir = new File (directory);
		scandir(dir, songs);
	}

	private void scandir (File dir, Vector songs) {
		File[] files;
		files = dir.listFiles();
		int i;

		if (files != null) {
			for (i = 0; i < files.length; ++i) {
				if (files[i].isFile()) {
					String type = files[i].getName().toLowerCase().substring(files[i].getName().length()-3);
					if (type.equals("ogg") || type.equals("mp3") ||
						type.equals("mod") || type.equals(".xm") || type.equals(".it") || type.equals("s3m")) {
						songs.add(new Song(files[i].getParent(), files[i].getName(), type, volumeId));
					}
				} else if (files[i].isDirectory()) {
					scandir(files[i], songs);
				}
			}
		}
	}
}

==> musiccontrol-0.3.tar.gz: musiccontrol-0.3/src/dk/borderworlds/MusicVolume.java <==
// $Id: MusicVolume.java,v 1.8 2005/02/24 17:52:57 xi Exp $

/******************************************************************************
*    MusicControl - An advanced music player
*    Copyright (C) 2002-2005  Christian Laursen <xi@borderworlds.dk>
*
*    This program is free software; you can redistribute it and/or modify
*    it under the terms of the GNU General Public License as published by
*    the Free Software Foundation; either version 2 of the License, or
*    (at your option) any later version.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU General Public License for more details.
*
*    You should have received a copy of the GNU General Public License
*    along with this program; if not, write to the Free Software
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

package dk.borderworlds;

import java.util.Vector;
import java.io.File;

public class MusicVolume {
	private String directory;
	private int volumeId;

	public MusicVolume (String directory, int volumeId) {
		this.directory = directory;
		this.volumeId = volumeId;
	}

	public String getDirectory () {
		return directory;
	}

	public int getVolumeId () {
		return volumeId;
	}

	public void rescan (Vector songs) {
		int i;
		Song song;

		for (i = 0; i < songs.size(); ++i) {
			song = (Song)songs.get(i);
			if (song.fromVolume(volumeId)) {
				songs.removeElementAt(i--);
			}
		}

		File dir = new File (directory);
		scandir(dir, songs);
	}

	private void scandir (File dir, Vector songs) {
		File[] files;
		files = dir.listFiles();
		int i;

		if (files != null) {
			for (i = 0; i < files.length; ++i) {
				if (files[i].isFile()) {
					String type = files[i].getName().toLowerCase().substring(files[i].getName().length()-3);
					if (type.equals("ogg") || type.equals("mp3") || type.equals("stm") ||
						type.equals("mod") || type.equals(".xm") || type.equals(".it") || type.equals("s3m")) {
						songs.add(new Song(files[i].getParent(), files[i].getName(), type, volumeId));
					}
				} else if (files[i].isDirectory()) {
					scandir(files[i], songs);
				}
			}
		}
	}
}
